==> prestashop_1.4.0.7.zip: prestashop/modules/dibs/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{dibs}prestashop>dibs_b508edd89d96e13df300b298143998d3'] = 'DIBS';
$_MODULE['<{dibs}prestashop>dibs_ef3a95ad5c00ef1b4d1d73d2b50bf54c'] = 'DIBS API de pago';
$_MODULE['<{dibs}prestashop>dibs_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuración modificada';
$_MODULE['<{dibs}prestashop>dibs_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuraciones';
$_MODULE['<{dibs}prestashop>dibs_794b8837b6ee6ddc4301f557915f9486'] = 'Color del logo';
$_MODULE['<{dibs}prestashop>dibs_44e1ec6255a91754e4911b16b9fc4d22'] = 'El color básico del logo que aparece en la página de pago';
$_MODULE['<{dibs}prestashop>dibs_765b8797a61e6d71133acf35dd0ca98f'] = 'id del vendedor';
$_MODULE['<{dibs}prestashop>dibs_b305acae66879c527cda4c4ded662585'] = 'Mirar el email enviado por DIBS';
$_MODULE['<{dibs}prestashop>dibs_f9986472f2190b1ec04c52dd1eca1af4'] = 'Utilizar el módulo de test de DIBS';
$_MODULE['<{dibs}prestashop>dibs_313ada9ae4162978238c99d505bb6870'] = 'Cuando este campo está declarado, la transacción no se envía al remitente de la carta sino al módulo de test de Twenga.';
$_MODULE['<{dibs}prestashop>dibs_41f538d798be040c3710e4e128105ad2'] = 'Mirar también la etapa 5 de la guía en 10 etapas para más información.';
$_MODULE['<{dibs}prestashop>dibs_97e7c9a7d06eac006a28bf05467fcc8b'] = 'Link';
$_MODULE['<{dibs}prestashop>dibs_5caf2f84c1d971f645728f50e76ef542'] = 'Durante su primera integración con DIBS, no necesita utilizar dicho parámetro, ya que todas las transacciones por defecto van a utilizar el sistema de test hasta que la integración del sitio no haya sido aprobada por DIBS. Si el sistema de test debe utilizarse posteriormente, puede activarse en DIBS (contacte con el soporte DIBS para reactivar el modo de test en su tienda)';
$_MODULE['<{dibs}prestashop>dibs_58768109d694bef3c059544892118901'] = 'Color de Flexwin';
$_MODULE['<{dibs}prestashop>dibs_37b0d284e5d29973b385ca537272ec38'] = 'El color del tema de Flexwi';
$_MODULE['<{dibs}prestashop>dibs_2e2b79996d4fb73bff9b97725ddfbab8'] = 'Url de aceptación';
$_MODULE['<{dibs}prestashop>dibs_cd034d4f983db501f3a1893d6b290939'] = 'La URL de la página que aparece si el pago es aceptado.';
$_MODULE['<{dibs}prestashop>dibs_fcb9c3f1b9731de08442d81583782db7'] = 'Anular la URL';
$_MODULE['<{dibs}prestashop>dibs_610d424aac114ec924b91ceee8119c63'] = 'La URL de la página que aparecerá si el usuario anula el pago';
$_MODULE['<{dibs}prestashop>dibs_b17f3f4dcf653a5776792498a9b44d6a'] = 'Modificar las configuraciones';
$_MODULE['<{dibs}prestashop>dibs_b64af11b4f643164b0b418c716a6f7a0'] = 'Pagar con DIBS';
$_MODULE['<{dibs}prestashop>dibs_fda89beb6740540db1053016d96624c3'] = 'Logo de DIBS';
$_MODULE['<{dibs}prestashop>dibs_eeaf35c1eb180cc38a77b892a96d7ed3'] = 'Pagar rápidamente de manera segura con DIBS';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Su pedido en';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'está terminado.';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Le enviaremos su pedido cuanto antes.';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Para cualquier pregunta o para más información, póngase en contacto con nuestro';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'servicio clientela';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Hemos observado un problema con su pedido. Si piensa que se trata de un error, puede ponerse en contacto con nuestro';

==> prestashop_1.4.0.9.zip: prestashop/modules/dibs/es.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{dibs}prestashop>dibs_b508edd89d96e13df300b298143998d3'] = 'DIBS';
$_MODULE['<{dibs}prestashop>dibs_ef3a95ad5c00ef1b4d1d73d2b50bf54c'] = 'DIBS API de pago';
$_MODULE['<{dibs}prestashop>dibs_9089b5cc02d13f0fa4c9b6d97861ea4f'] = 'Por razones de seguridad, debe grabar las claves 1 y 2 utilizadas por el control MD de el API de DIBS.';
$_MODULE['<{dibs}prestashop>dibs_a71f6529f183021aca50cf8dd3b92872'] = 'Debe registrar su ID vendedor para utilizar el API de DIBS.';
$_MODULE['<{dibs}prestashop>dibs_20015706a8cbd457cbb6ea3e7d5dc9b3'] = 'Configuración modificada';
$_MODULE['<{dibs}prestashop>dibs_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuraciones';
$_MODULE['<{dibs}prestashop>dibs_794b8837b6ee6ddc4301f557915f9486'] = 'Color del logo';
$_MODULE['<{dibs}prestashop>dibs_44e1ec6255a91754e4911b16b9fc4d22'] = 'El color básico del logo que aparece en la página de pago';
$_MODULE['<{dibs}prestashop>dibs_765b8797a61e6d71133acf35dd0ca98f'] = 'id del vendedor';
$_MODULE['<{dibs}prestashop>dibs_b305acae66879c527cda4c4ded662585'] = 'Mirar el email enviado por DIBS';
$_MODULE['<{dibs}prestashop>dibs_310fc01b7a8c167aa514ccccc9e46e99'] = 'Clave de seguridad n°1';
$_MODULE['<{dibs}prestashop>dibs_247cc6885be1cb649d05acf81242cc35'] = 'Clave de seguridad n°2';
$_MODULE['<{dibs}prestashop>dibs_eccc618d6b2ca6c4479db14d9ab2b301'] = 'Estas claves se utilizan para mejorar la seguridad';
$_MODULE['<{dibs}prestashop>dibs_fad8e2c009f82d777e3143342aa6b7e8'] = 'Puede recuperar estas claves en la interfaz de administración de DIBS en el menú Integración > MD5 keys. No se olvide de comprobar si el controls MD5 se encuentra acitivado, si no el módulo no será funcional.';
$_MODULE['<{dibs}prestashop>dibs_f9986472f2190b1ec04c52dd1eca1af4'] = 'Utilizar el módulo de test de DIBS';
$_MODULE['<{dibs}prestashop>dibs_313ada9ae4162978238c99d505bb6870'] = 'Cuando este campo está declarado, la transacción no se envía al remitente de la carta sino al módulo de test de Twenga.';
$_MODULE['<{dibs}prestashop>dibs_41f538d798be040c3710e4e128105ad2'] = 'Mirar también la etapa 5 de la guía en 10 etapas para más información.';
$_MODULE['<{dibs}prestashop>dibs_97e7c9a7d06eac006a28bf05467fcc8b'] = 'Link';
$_MODULE['<{dibs}prestashop>dibs_5caf2f84c1d971f645728f50e76ef542'] = 'Durante su primera integración con DIBS, no necesita utilizar dicho parámetro, ya que todas las transacciones por defecto van a utilizar el sistema de test hasta que la integración del sitio no haya sido aprobada por DIBS. Si el sistema de test debe utilizarse posteriormente, puede activarse en DIBS (contacte con el soporte DIBS para reactivar el modo de test en su tienda)';
$_MODULE['<{dibs}prestashop>dibs_58768109d694bef3c059544892118901'] = 'Color de Flexwin';
$_MODULE['<{dibs}prestashop>dibs_37b0d284e5d29973b385ca537272ec38'] = 'El color del tema de Flexwi';
$_MODULE['<{dibs}prestashop>dibs_2e2b79996d4fb73bff9b97725ddfbab8'] = 'Url de aceptación';
$_MODULE['<{dibs}prestashop>dibs_cd034d4f983db501f3a1893d6b290939'] = 'La URL de la página que aparece si el pago es aceptado.';
$_MODULE['<{dibs}prestashop>dibs_fcb9c3f1b9731de08442d81583782db7'] = 'Anular la URL';
$_MODULE['<{dibs}prestashop>dibs_610d424aac114ec924b91ceee8119c63'] = 'La URL de la página que aparecerá si el usuario anula el pago';
$_MODULE['<{dibs}prestashop>dibs_b17f3f4dcf653a5776792498a9b44d6a'] = 'Modificar las configuraciones';
$_MODULE['<{dibs}prestashop>dibs_b64af11b4f643164b0b418c716a6f7a0'] = 'Pagar con DIBS';
$_MODULE['<{dibs}prestashop>dibs_fda89beb6740540db1053016d96624c3'] = 'Logo de DIBS';
$_MODULE['<{dibs}prestashop>dibs_eeaf35c1eb180cc38a77b892a96d7ed3'] = 'Pagar rápidamente de manera segura con DIBS';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Su pedido en';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'está terminado.';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_30163d8fc3068e8297e7ab5bf32aec87'] = 'Le enviaremos su pedido cuanto antes.';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Para cualquier pregunta o para más información, póngase en contacto con nuestro';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'servicio clientela';
$_MODULE['<{dibs}prestashop>hookorderconfirmation_8de637e24570c1edb0357826a2ad5aea'] = 'Hemos observado un problema con su pedido. Si piensa que se trata de un error, puede ponerse en contacto con nuestro';
